==> open-xchange-rest_7.8.4.orig.tar.bz2: open-xchange-rest-7.8.4/com.openexchange.rest.services.database/src/com/openexchange/rest/services/database/osgi/DatabaseRESTActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.rest.services.database.osgi;

import java.util.Arrays;
import java.util.Collection;
import java.util.concurrent.TimeUnit;
import com.openexchange.database.CreateTableService;
import com.openexchange.database.DatabaseService;
import com.openexchange.groupware.update.UpdateTaskProviderService;
import com.openexchange.groupware.update.UpdateTaskV2;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.rest.services.database.DatabaseRESTService;
import com.openexchange.rest.services.database.internal.DatabaseEnvironment;
import com.openexchange.rest.services.database.migrations.DBVersionChecker;
import com.openexchange.rest.services.database.sql.CreateServiceSchemaLockTable;
import com.openexchange.rest.services.database.sql.CreateServiceSchemaLockTableTask;
import com.openexchange.rest.services.database.sql.CreateServiceSchemaVersionTable;
import com.openexchange.rest.services.database.sql.CreateServiceSchemaVersionTableTask;
import com.openexchange.rest.services.database.sql.SetDBEngineUpdateTask;
import com.openexchange.rest.services.database.transactions.InMemoryTransactionKeeper;
import com.openexchange.timer.TimerService;

/**
 * {@link DatabaseRESTActivator}
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public class DatabaseRESTActivator extends HousekeepingActivator {

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { DatabaseService.class, TimerService.class };
    }

    @Override
    protected void startBundle() throws Exception {
        Services.setServiceLookup(this);
        final InMemoryTransactionKeeper txKeeper = new InMemoryTransactionKeeper();
        final DBVersionChecker versionChecker = new DBVersionChecker();

        getService(TimerService.class).scheduleAtFixedRate(new Runnable() {

            @Override
            public void run() {
                txKeeper.tick(System.currentTimeMillis());
            }
        }, 2, 1, TimeUnit.MINUTES);

        registerService(DatabaseRESTService.class, new DatabaseRESTService(this, new DatabaseEnvironment(txKeeper, versionChecker)));

        registerService(CreateTableService.class, new CreateServiceSchemaVersionTable());
        registerService(CreateTableService.class, new CreateServiceSchemaLockTable());

        registerService(UpdateTaskProviderService.class, new UpdateTaskProviderService() {

            @Override
            public Collection<? extends UpdateTaskV2> getUpdateTasks() {
                return Arrays.asList(new CreateServiceSchemaVersionTableTask(getService(DatabaseService.class)), new CreateServiceSchemaLockTableTask(getService(DatabaseService.class)), new SetDBEngineUpdateTask());
            }
        });
    }
}

==> open-xchange-rest_7.10.0.orig.tar.bz2: open-xchange-rest-7.10.0/com.openexchange.rest.services.database/src/com/openexchange/rest/services/database/osgi/DatabaseRESTActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.rest.services.database.osgi;

import java.util.Arrays;
import java.util.concurrent.TimeUnit;
import com.openexchange.database.CreateTableService;
import com.openexchange.database.DatabaseService;
import com.openexchange.groupware.update.UpdateTaskProviderService;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.rest.services.database.DatabaseRESTService;
import com.openexchange.rest.services.database.internal.DatabaseEnvironment;
import com.openexchange.rest.services.database.migrations.DBVersionChecker;
import com.openexchange.rest.services.database.sql.CreateServiceSchemaLockTable;
import com.openexchange.rest.services.database.sql.CreateServiceSchemaLockTableTask;
import com.openexchange.rest.services.database.sql.CreateServiceSchemaVersionTable;
import com.openexchange.rest.services.database.sql.CreateServiceSchemaVersionTableTask;
import com.openexchange.rest.services.database.sql.ServiceSchemaConvertUtf8ToUtf8mb4UpdateTask;
import com.openexchange.rest.services.database.transactions.InMemoryTransactionKeeper;
import com.openexchange.timer.TimerService;

/**
 * {@link DatabaseRESTActivator}
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public class DatabaseRESTActivator extends HousekeepingActivator {

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { DatabaseService.class, TimerService.class };
    }

    @Override
    protected void startBundle() throws Exception {
        final InMemoryTransactionKeeper txKeeper = new InMemoryTransactionKeeper();
        final DBVersionChecker versionChecker = new DBVersionChecker();

        getService(TimerService.class).scheduleAtFixedRate(() -> txKeeper.tick(System.currentTimeMillis()), 2, 1, TimeUnit.MINUTES);

        registerService(DatabaseRESTService.class, new DatabaseRESTService(this, new DatabaseEnvironment(txKeeper, versionChecker)));

        registerService(CreateTableService.class, new CreateServiceSchemaVersionTable());
        registerService(CreateTableService.class, new CreateServiceSchemaLockTable());

        registerService(UpdateTaskProviderService.class, () -> Arrays.asList(new CreateServiceSchemaVersionTableTask(getService(DatabaseService.class)), new CreateServiceSchemaLockTableTask(getService(DatabaseService.class)), new ServiceSchemaConvertUtf8ToUtf8mb4UpdateTask()));
    }
}
